Class: Fleakr::Objects::Error
- Inherits:
-
Object
- Object
- Fleakr::Objects::Error
- Includes:
- Support::Object
- Defined in:
- lib/fleakr/objects/error.rb
Overview
Error
Accessors
This class is a simple wrapper for the error response that the API returns. There are a couple of attributes:
[code] The error code as described in the documentation [message] The associated error message